@@ -15,8 +15,8 @@
  *  
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.  
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.  
  */
 
 #include "config.h"
@@ -723,7 +723,7 @@ handle_pkcs12_cert_bag (GcrParser *self, const guchar *data, gsize n_data)
 {
 	GNode *asn = NULL;
 	GNode *asn_content = NULL;
-	guchar *certificate;
+	guchar *certificate = NULL;
 	const guchar *element;
 	gsize n_certificate, n_element;
 	gint ret;
