@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include "config.h"
@@ -537,7 +537,7 @@ get_unlock_options_from_prompt (GkmWrapPrompt *self, CK_ULONG_PTR n_options)
 static void
 set_unlock_options_on_prompt (GkmWrapPrompt *self, CK_ATTRIBUTE_PTR options, CK_ULONG n_options)
 {
-	const gchar *choice;
+	const gchar *choice = NULL;
 	gboolean have_ttl = FALSE;
 	gboolean bval;
 	gulong uval;
@@ -561,8 +561,9 @@ set_unlock_options_on_prompt (GkmWrapPrompt *self, CK_ATTRIBUTE_PTR options, CK_
 		have_ttl = TRUE;
 		ttl = uval;
 	}
-
-	gku_prompt_set_unlock_choice (GKU_PROMPT (self), choice);
+        
+        if (choice != NULL)
+	        gku_prompt_set_unlock_choice (GKU_PROMPT (self), choice);
 	if (have_ttl)
 		gku_prompt_set_unlock_ttl (GKU_PROMPT (self), ttl);
 }
