@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
- * 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+ * 02110-1301, USA.
  */
 
 #include "config.h"
@@ -271,7 +271,7 @@ create_assertions (void)
 static GkmAssertion*
 create_assertion (GkmXdgTrust *self, GNode *asn)
 {
-	CK_X_ASSERTION_TYPE type;
+	CK_X_ASSERTION_TYPE type = 0UL;
 	GkmAssertion *assertion;
 	GQuark level;
 	gchar *purpose;
